function phi_detected=PC_Determine_Biggest_Phi_Given_Position(X,Y,incremento)
%% Funcao para descobrir o maior valor de phi para uma dada posição no espaço (PERNA LIVRE)
% INPUT
% x - posição horizontal relativamente à cota do tornozelo
% y - posição vertical relativamente à base do pé
% incremento - resolução do cálculo
% OUTPUT
% phi_detected - phi calculado mais perto do valor zero

phis=[];

phi=[-90:incremento:0,0+incremento:incremento:90];

for i=1:size(phi,2)
    [ANCA , ~, ~]=PC_Inv_Kin_Perna_Livre(X,Y,phi(i));
    if ~isempty(ANCA)
        phis=[phis;phi(i)];
    end
end

% o melhor phi sera sempre o mais próximo de zero
[~, idx0] = max(phis);
phi_detected=phis(idx0);



end